summaryrefslogtreecommitdiffstats
path: root/web-tools/bin/tools.py
diff options
context:
space:
mode:
Diffstat (limited to 'web-tools/bin/tools.py')
-rwxr-xr-xweb-tools/bin/tools.py10
1 files changed, 9 insertions, 1 deletions
diff --git a/web-tools/bin/tools.py b/web-tools/bin/tools.py
index bf1a067..3bb6a9e 100755
--- a/web-tools/bin/tools.py
+++ b/web-tools/bin/tools.py
@@ -18,7 +18,7 @@
# along with this program. If not, see <http://www.gnu.org/licenses/>.
# Dependencies:
# sudo apt install iputils-ping traceroute whois nmap testssl.sh geoip-bin geoip-database knot-dnsutils
from cgi import FieldStorage
from datetime import datetime
@@ -214,6 +214,14 @@ def main():
else:
options = ' '
#-O -T5
+ elif Command == 'ssh-audit':
+ if Protocol == 'ipv6-only':
+ options = ' -6'
+ elif Protocol == 'ipv4-only':
+ options = ' -4'
+ else:
+ options = ''
+ options = options + ' --no-colors '
elif Command == 'testssl':
options = ' --color 0 '
elif Command == 'whois':
@@ -18,7 +18,7 @@
# along with this program. If not, see <http://www.gnu.org/licenses/>.
# Dependencies:
-# sudo apt install iputils-ping traceroute whois nmap testssl.sh geoip-bin geoip-database knot-dnsutils
+# sudo apt install iputils-ping traceroute whois nmap ssh-audit testssl.sh geoip-bin geoip-database knot-dnsutils
from cgi import FieldStorage
from datetime import datetime